@@ -21,9 +21,12 @@ SPREADSHEET_VALUES_APPEND_URL = SPREADSHEET_VALUES_URL + ":append"
 SPREADSHEET_VALUES_CLEAR_URL = SPREADSHEET_VALUES_URL + ":clear"
 SPREADSHEET_SHEETS_COPY_TO_URL = SPREADSHEET_URL + "/sheets/%s:copyTo"
 
-DRIVE_FILES_API_V2_URL = "https://www.googleapis.com/drive/v2/files"
 DRIVE_FILES_API_V3_URL = "https://www.googleapis.com/drive/v3/files"
 DRIVE_FILES_UPLOAD_API_V2_URL = "https://www.googleapis.com" "/upload/drive/v2/files"
 
+DRIVE_FILES_API_V3_COMMENTS_URL = (
+    "https://www.googleapis.com/drive/v3/files/%s/comments"
+)
+
 SPREADSHEET_DRIVE_URL = "https://docs.google.com/spreadsheets/d/%s"
-WORKSHEET_DRIVE_URL = SPREADSHEET_URL + "#gid=%s"
+WORKSHEET_DRIVE_URL = SPREADSHEET_DRIVE_URL + "#gid=%s"
